@@ -137,8 +137,12 @@ class DBManager(object):
         for data_key in data_keys:
             if data_key not in table_keys:
                 for it in data:
-                    if it.get(data_key) is not None:
+                    try:
+                        # 值是None 也要删。但如果没有key，就会except
                         del it[data_key]
+                    except:
+                        # 要删除的key不存在。
+                        pass
         return table_keys
 
     def align_data_keys(self, data, table):
